# CLI ([fsaccone](https://pypi.org/project/fsaccone/))
A CLI that creates opinionated project templates.

## Installation
> `pip install fsaccone`

## Usage
> `fsaccone --template <TEMPLATE>`

## Flags
- `--template` / `-t` `<TEMPLATE>`            - The name of the template to utilize.
- `--directory` / `-dir` / `-d` `<DIRECTORY>` - The directory to build the template in.
- `-y`                                        - Skips the confirmation alert.

## License
[MIT License](LICENSE.txt)
